@@ -1,8 +1,5 @@
 package Dancer::Exception;
-our $AUTHORITY = 'cpan:SUKRIA';
-#ABSTRACT: class for throwing and catching exceptions
-$Dancer::Exception::VERSION = '1.3514_04'; # TRIAL
-$Dancer::Exception::VERSION = '1.351404';
+
 use strict;
 use warnings;
 use Carp;
@@ -52,7 +49,7 @@ sub continuation (&;@) {
       },  'Try::Tiny::Catch') , @new_rest);
 
     return ( bless ( \ sub {
-          ref && blessed($_) && $_->isa('Dancer::Continuation')
+          ref && $_->isa('Dancer::Continuation')
             ? $block->(@_) : die($_);
       }, 'Try::Tiny::Catch'), @new_rest );
 }
@@ -107,23 +104,22 @@ sub registered_exceptions {
 
 register_exception(@$_) foreach (
     [ 'Core',                message_pattern => 'core - %s' ],
-    [ 'Core::App',           message_pattern => 'core - app - %s',         composed_from => [ qw(Core) ] ],
-    [ 'Core::Config',        message_pattern => 'core - config - %s',      composed_from => [ qw(Core) ] ],
-    [ 'Core::Deprecation',   message_pattern => 'core - deprecation - %s', composed_from => [ qw(Core) ] ],
-    [ 'Core::Engine',        message_pattern => 'core - engine - %s',      composed_from => [ qw(Core) ] ],
-    [ 'Core::Factory',       message_pattern => 'core - factory - %s',     composed_from => [ qw(Core) ] ],
-    [ 'Core::Factory::Hook', message_pattern => 'core - hook - %s',        composed_from => [ qw(Core::Factory) ] ],
-    [ 'Core::Hook',          message_pattern => 'core - hook - %s',        composed_from => [ qw(Core) ] ],
-    [ 'Core::Fileutils',     message_pattern => 'core - file utils - %s',  composed_from => [ qw(Core) ] ],
-    [ 'Core::Handler',       message_pattern => 'core - handler - %s',     composed_from => [ qw(Core) ] ],
-    [ 'Core::Handler::PSGI', message_pattern => 'core - handler - %s',     composed_from => [ qw(Core::Handler) ] ],
-    [ 'Core::Plugin',        message_pattern => 'core - plugin - %s',      composed_from => [ qw(Core) ] ],
-    [ 'Core::Renderer',      message_pattern => 'core - renderer - %s',    composed_from => [ qw(Core) ] ],
-    [ 'Core::Request',       message_pattern => 'core - request - %s',     composed_from => [ qw(Core) ] ],
-    [ 'Core::Route',         message_pattern => 'core - route - %s',       composed_from => [ qw(Core) ] ],
-    [ 'Core::Serializer',    message_pattern => 'core - serializer - %s',  composed_from => [ qw(Core) ] ],
-    [ 'Core::Template',      message_pattern => 'core - template - %s',    composed_from => [ qw(Core) ] ],
-    [ 'Core::Session',       message_pattern => 'core - session - %s',     composed_from => [ qw(Core) ] ],
+    [ 'Core::App',           message_pattern => 'app - %s',         composed_from => [ qw(Core) ] ],
+    [ 'Core::Config',        message_pattern => 'config - %s',      composed_from => [ qw(Core) ] ],
+    [ 'Core::Deprecation',   message_pattern => 'deprecation - %s', composed_from => [ qw(Core) ] ],
+    [ 'Core::Engine',        message_pattern => 'engine - %s',      composed_from => [ qw(Core) ] ],
+    [ 'Core::Factory',       message_pattern => 'factory - %s',     composed_from => [ qw(Core) ] ],
+    [ 'Core::Factory::Hook', message_pattern => 'hook - %s',        composed_from => [ qw(Core::Factory) ] ],
+    [ 'Core::Hook',          message_pattern => 'hook - %s',        composed_from => [ qw(Core) ] ],
+    [ 'Core::Fileutils',     message_pattern => 'file utils - %s',  composed_from => [ qw(Core) ] ],
+    [ 'Core::Handler',       message_pattern => 'handler - %s',     composed_from => [ qw(Core) ] ],
+    [ 'Core::Handler::PSGI', message_pattern => 'handler - %s',     composed_from => [ qw(Core::Handler) ] ],
+    [ 'Core::Plugin',        message_pattern => 'plugin - %s',      composed_from => [ qw(Core) ] ],
+    [ 'Core::Renderer',      message_pattern => 'renderer - %s',    composed_from => [ qw(Core) ] ],
+    [ 'Core::Route',         message_pattern => 'route - %s',       composed_from => [ qw(Core) ] ],
+    [ 'Core::Serializer',    message_pattern => 'serializer - %s',  composed_from => [ qw(Core) ] ],
+    [ 'Core::Template',      message_pattern => 'template - %s',    composed_from => [ qw(Core) ] ],
+    [ 'Core::Session',       message_pattern => 'session - %s',     composed_from => [ qw(Core) ] ],
 );
 
 1;
@@ -132,16 +128,10 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Dancer::Exception - class for throwing and catching exceptions
 
-=head1 VERSION
-
-version 1.3514_04
-
 =head1 SYNOPSIS
 
     use Dancer::Exception qw(:all);
@@ -167,6 +157,8 @@ version 1.3514_04
       }
     };
 
+
+
 =head1 DESCRIPTION
 
 Dancer::Exception is based on L<Try::Tiny>. You can try and catch exceptions,
@@ -219,17 +211,17 @@ To be used by Dancer developers only, in Dancer core code.
   raise '+My::Own::ExceptionSystem::Invalid::Login' => "user $username is unknown";
 
 raise provides an easy way to throw an exception. First parameter is the name
-of the exception class, without the C<Dancer::Exception::> prefix. other
+of the exception class, without the C<Dancer::Exception::Base::> prefix. other
 parameters are stored as I<raising arguments> in the exception. Usually the
 parameters is an exception message, but it's left to the exception class
 implementation.
 
 If the exception class name starts with a C<+>, then the
-C<Dancer::Exception::> won't be added. This allows one to build their own
+C<Dancer::Exception::Base::> won't be added. This allows one to build their own
 exception class hierarchy, but you should first look at C<register_exception>
 before implementing your own class hierarchy. If you really wish to build your
 own exception class hierarchy, we recommend that all exceptions inherit of
-L<Dancer::Exception::>. Or at least it should implement its methods.
+L<Dancer::Exception::Base>. Or at least it should implement its methods.
 
 The exception class can also be written as words separated by underscores, it'll be
 camelized automatically. So C<'Exception::Foo'> and C<'exception_foo'> are
@@ -250,7 +242,7 @@ This registers a new custom exception. To use it, do:
 
   raise InvalidCredentials => "user Herbert not found";
 
-The exception message can be retrieved with the C<$exception-E<gt>message> method, and we'll be
+The exception message can be retrieved with the C<$exception->message> method, and we'll be
 C<"invalid credentials : user Herbert not found"> (see methods in L<Dancer::Exception::Base>)
 
   # complex exception
@@ -283,16 +275,3 @@ is similar to C<$Carp::Verbose>. I recommend you use it like that:
 
 All the L<Carp> global variables can also be used to alter the stacktrace
 generation.
-
-=head1 AUTHOR
-
-Dancer Core Developers
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Alexis Sukrieh.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
