@@ -1,8 +1,5 @@
 package Dancer::Exception::Base;
-our $AUTHORITY = 'cpan:SUKRIA';
-#ABSTRACT: the base class of all Dancer exceptions
-$Dancer::Exception::Base::VERSION = '1.3514_04'; # TRIAL
-$Dancer::Exception::Base::VERSION = '1.351404';
+
 use strict;
 use warnings;
 use Carp;
@@ -60,6 +57,14 @@ sub message {
     my ($self) = @_;
     my $message_pattern = $self->_message_pattern;
     my $message = sprintf($message_pattern, @{$self->_raised_arguments});
+    my @composition = (reverse $self->get_composition);
+    shift @composition;
+    foreach my $component (@composition) {
+        my $class = "Dancer::Exception::$component";
+        no strict 'refs';
+        my $pattern = $class->_message_pattern;
+        $message = sprintf($pattern, $message);
+    }
     return $message;
 }
 
@@ -72,20 +77,8 @@ sub does {
 sub get_composition {
     my ($self) = @_;
     my $class = ref($self);
-
-    my ($_recurse_isa, %seen);
-    $_recurse_isa = sub {
-        my ($class) = @_;
-        $seen{$class}++
-          and return;
-
-        no strict 'refs';
-        return $class, map { $_recurse_isa->($_) }
-                      grep { /^Dancer::Exception::/ }
-                          @{"${class}::ISA"};
-        
-    };
-    grep { s/^Dancer::Exception::// } $_recurse_isa->($class);
+    my @isa = do { no strict 'refs'; @{"${class}::ISA"}, $class };
+    return grep { s|^Dancer::Exception::|| } @isa;
 }
 
 sub _raised_arguments {
@@ -100,16 +93,10 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Dancer::Exception::Base - the base class of all Dancer exceptions
 
-=head1 VERSION
-
-version 1.3514_04
-
 =head1 DESCRIPTION
 
 Dancer::Exception::Base is the base class of all Dancer exception. All core
@@ -163,23 +150,21 @@ multiple types at once. C<does> performs a logical OR between them:
 
 =head2 get_composition
 
-Returns the composed types of an exception. As every exception inherits of
-Dancer::Exception::Base, the returned list contains at least 'Base', and the
-exception class name.
-
+Returns the type or the composed types of an exception.
 B<Warning>, the result is a list, so you should call this method in list context.
 
   try { raise InvalidPassword => 'foo'; }
   catch {
     my ($e) = @_;
     my @list = $e->get_composition()
-    # @list contains ( 'InvalidPassword', 'Base', ... )
+    # @list contains ( 'InvalidPassword' )
   };
 
 =head2 message
 
 Computes and returns the message associated to the exception. It'll apply the
-parameters that were set at throw time to the message pattern of the exception.
+parameters that were set at throw time to the message patterns of all the class
+that composes the exception.
 
 =head1 STRINGIFICATION
 
@@ -192,7 +177,7 @@ return their message, concatenated with their stack trace (see below).
 
 The C<cmp> operator is also overloaded, thus all the string operations can be
 done on Dancer's exceptions, as they will all be based on the overloaded C<cmp>
-operator. Dancer exceptions will be compared B<without> their stacktraces.
+operator. Dancer exceptions wil be compared B<without> their stacktraces.
 
 =head1 STACKTRACE
 
@@ -221,16 +206,3 @@ is similar to C<$Carp::Verbose>. I recommend you use it like that:
 
 All the L<Carp> global variables can also be used to alter the stacktrace
 generation.
-
-=head1 AUTHOR
-
-Dancer Core Developers
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by Alexis Sukrieh.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
