@@ -6,9 +6,11 @@ use warnings;
 use Dancer ':syntax';
 use Dancer::Plugin;
 
+our $VERSION = '1.00';
+
 register 'ajax' => \&ajax;
 
-before sub {
+hook before => sub {
     if (request->is_ajax) {
         content_type('text/xml');
     }
