@@ -9,6 +9,7 @@ use base 'Dancer::Object';
 use Dancer::Config 'setting';
 use Dancer::Request::Upload;
 use Dancer::SharedData;
+use Dancer::Exception qw(:all);
 use Encode;
 use HTTP::Body;
 use URI;
@@ -28,7 +29,7 @@ __PACKAGE__->attributes(
     'content_type', 'content_length',
     'body',         'id',
     'uploads',      'headers', 'path_info',
-    'ajax',         'body_is_parsed',
+    'ajax',         'is_forward',
     @http_env_keys,
 );
 
@@ -37,7 +38,7 @@ sub new {
     if (@args == 1) {
         @args = ('env' => $args[0]);
         Dancer::Deprecation->deprecated(
-                      fatal   => 0,
+                      fatal   => 1,
                       feature => 'Calling Dancer::Request->new($env)',
                       version => 1.3059,
                       reason  => 'Please use Dancer::Request->new( env => $env ) instead',
@@ -56,7 +57,7 @@ sub host {
         $_[0]->{host} = $_[1];
     } else {
         my $host;
-        $host = $_[0]->env->{X_FORWARDED_HOST} if setting('behind_proxy');
+        $host = ($_[0]->env->{X_FORWARDED_HOST} || $_[0]->env->{HTTP_X_FORWARDED_HOST}) if setting('behind_proxy');
         $host || $_[0]->{host} || $_[0]->env->{HTTP_HOST};
     }
 }
@@ -87,6 +88,7 @@ sub is_post               { $_[0]->{method} eq 'POST' }
 sub is_get                { $_[0]->{method} eq 'GET' }
 sub is_put                { $_[0]->{method} eq 'PUT' }
 sub is_delete             { $_[0]->{method} eq 'DELETE' }
+sub is_patch              { $_[0]->{method} eq 'PATCH' }
 sub header                { $_[0]->{headers}->header($_[1]) }
 
 # public interface compat with CGI.pm objects
@@ -102,7 +104,7 @@ sub init {
     $self->{method}         = undef;
     $self->{params}         = {};
     $self->{body}           = '';
-    $self->{body_is_parsed} ||= 0;
+    $self->{is_forward}     ||= 0;
     $self->{content_length} = $self->env->{CONTENT_LENGTH} || 0;
     $self->{content_type}   = $self->env->{CONTENT_TYPE} || '';
     $self->{id}             = ++$count;
@@ -159,7 +161,7 @@ sub forward {
     my $env = $request->env;
     $env->{PATH_INFO} = $to_data->{to_url};
 
-    my $new_request = $class->new(env => $env, body_is_parsed => 1);
+    my $new_request = $class->new(env => $env, is_forward => 1);
     my $new_params  = _merge_params(scalar($request->params),
                                     $to_data->{params} || {});
 
@@ -274,7 +276,7 @@ sub params {
         return $self->{_route_params};
     }
     else {
-        croak "Unknown source params \"$source\".";
+        raise core_request => "Unknown source params \"$source\".";
     }
 }
 
@@ -373,7 +375,7 @@ sub _build_params {
 
     # now parse environement params...
     $self->_parse_get_params();
-    if ($self->{body_is_parsed}) {
+    if ($self->is_forward) {
         $self->{_body_params} ||= {};
     } else {
         $self->_parse_post_params();
@@ -402,7 +404,7 @@ sub _build_path {
         $path ||= $self->_url_decode($self->request_uri);
     }
 
-    croak "Cannot resolve path" if not $path;
+    raise core_request => "Cannot resolve path" if not $path;
     $self->{path} = $path;
 }
 
@@ -514,7 +516,7 @@ sub _read {
         return $buffer;
     }
     else {
-        croak "Unknown error reading input: $!";
+        raise core_request => "Unknown error reading input: $!";
     }
 }
 
@@ -592,8 +594,8 @@ It uses the environment hash table given to build the request object:
 
     Dancer::Request->new(env => \%ENV);
 
-It also accepts the C<body_is_parsed> boolean flag, if the new request object should
-not parse request body.
+It also accepts the C<is_forward> boolean flag, if the new request
+object is the result of a forward.
 
 =head2 init()
 
@@ -678,6 +680,10 @@ Return true if the method requested by the client is 'GET'
 
 Return true if the method requested by the client is 'HEAD'
 
+=head2 is_patch()
+
+Return true if the method requested by the client is 'PATCH'
+
 =head2 is_post()
 
 Return true if the method requested by the client is 'POST'
