@@ -4,9 +4,10 @@ use strict;
 use warnings;
 use Carp;
 
+use Dancer::Logger;
 use Dancer::Factory::Hook;
-use Dancer::Deprecation;
 use Dancer::FileUtils 'path';
+use Dancer::Exception qw(:all);
 
 use base 'Dancer::Engine';
 
@@ -21,30 +22,49 @@ sub render { confess "render not implemented" }
 
 sub default_tmpl_ext { "tt" }
 
+# Work out the template names to look for; this will be the view name passed
+# as-is, and also the view name with the default template extension appended, if
+# it did not already end in that.
 sub _template_name {
     my ( $self, $view ) = @_;
+    my @views = ( $view );
     my $def_tmpl_ext = $self->config->{extension} || $self->default_tmpl_ext();
-    $view .= ".$def_tmpl_ext" if $view !~ /\.\Q$def_tmpl_ext\E$/;
-    return $view;
+    push @views, $view .= ".$def_tmpl_ext" if $view !~ /\.\Q$def_tmpl_ext\E$/;
+    return @views;
 }
 
 sub view {
     my ($self, $view) = @_;
 
-    $view = $self->_template_name($view);
+    my $views_dir = Dancer::App->current->setting('views');
 
-    return path(Dancer::App->current->setting('views'), $view);
+    for my $template ($self->_template_name($view)) {
+        my $view_path = path($views_dir, $template);
+        return $view_path if -e $view_path;
+    }
+
+    # No matching view path was found
+    return;
 }
 
 sub layout {
     my ($self, $layout, $tokens, $content) = @_;
 
-    my $layout_name = $self->_template_name($layout);
-    my $layout_path = path(Dancer::App->current->setting('views'), 'layouts', $layout_name);
+    my $layouts_dir = path(Dancer::App->current->setting('views'), 'layouts');
+    my $layout_path;
+    for my $layout_name ($self->_template_name($layout)) {
+        $layout_path = path($layouts_dir, $layout_name);
+        last if -e $layout_path;
+    }
 
-    my $full_content =
-      Dancer::Template->engine->render($layout_path,
-        {%$tokens, content => $content});
+    my $full_content;
+    if (-e $layout_path) {
+        $full_content = Dancer::Template->engine->render(
+                                     $layout_path, {%$tokens, content => $content});
+    } else {
+        $full_content = $content;
+        Dancer::Logger::error("Defined layout ($layout) was not found!");
+    }
     $full_content;
 }
 
@@ -57,7 +77,16 @@ sub apply_renderer {
 
     Dancer::Factory::Hook->execute_hooks('before_template_render', $tokens);
 
-    my $content = $self->render($view, $tokens);
+    my $content;
+    try {
+        $content = $self->render($view, $tokens);
+    } continuation {
+        my ($continuation) = @_;
+        # If we have a Route continuation, run the after hook, then
+        # propagate the continuation
+        Dancer::Factory::Hook->execute_hooks('after_template_render', \$content);
+        $continuation->rethrow();
+    };
 
     Dancer::Factory::Hook->execute_hooks('after_template_render', \$content);
 
@@ -87,8 +116,17 @@ sub apply_layout {
 
     Dancer::Factory::Hook->execute_hooks('before_layout_render', $tokens, \$content);
 
-    my $full_content =
-      $self->layout($layout, $tokens, $content);
+    my $full_content;
+
+    try {
+        $full_content = $self->layout($layout, $tokens, $content);
+    } continuation {
+        my ($continuation) = @_;
+        # If we have a Route continuation, run the after hook, then
+        # propagate the continuation
+        Dancer::Factory::Hook->execute_hooks('after_layout_render', \$full_content);
+        $continuation->rethrow();
+    };
 
     Dancer::Factory::Hook->execute_hooks('after_layout_render', \$full_content);
 
@@ -123,31 +161,37 @@ sub _prepare_tokens_options {
     return ($tokens, $options);
 }
 
-sub _render_with_layout {
-    my ($class, $content, $tokens, $options) = @_;
-
-    Dancer::Deprecation::deprecated(
-        feature => 'render_with_layout',
-        version => '1.3000',
-        fatal   => 1,
-        reason  => "use the 'engine' keyword to get the template engine, and use 'apply_layout' on the result",
-    );
-}
-
 sub template {
     my ($class, $view, $tokens, $options) = @_;
     my ($content, $full_content);
 
+    my $engine = Dancer::Template->engine;
+
     # it's important that $tokens is not undef, so that things added to it via
     # a before_template in apply_renderer survive to the apply_layout. GH#354
     $tokens  ||= {};
     $options ||= {};
 
-    $content = $view ? Dancer::Template->engine->apply_renderer($view, $tokens)
-                     : delete $options->{content};
+    if ($view) {
+        # check if the requested view exists
+        my $view_path = $engine->view($view);
+        if ($engine->view_exists($view_path)) {
+            $content = $engine->apply_renderer($view, $tokens);
+        } else {
+            Dancer::Logger::error(
+                "Supplied view ($view) not found - $view_path does not exist"
+            );
+            return Dancer::Error->new(
+                          code => 500,
+                          message => 'view not found',
+                   )->render();
+        }
+    } else {
+        $content = delete $options->{content};
+    }
 
     defined $content and $full_content =
-      Dancer::Template->engine->apply_layout($content, $tokens, $options);
+      $engine->apply_layout($content, $tokens, $options);
 
     defined $full_content
       and return $full_content;
@@ -158,6 +202,8 @@ sub template {
     )->render();
 }
 
+sub view_exists { return -e $_[1] }
+
 1;
 __END__
 
@@ -244,11 +290,32 @@ configuration. For example, for the default (C<Simple>) engine:
 
 =item B<view($view)>
 
-The default behavior of this method is to return the path of the given view.
+The default behavior of this method is to return the path of the given view,
+appending the default template extension (either the value of the C<extension>
+setting in the configuration, or the value returned by C<default_tmpl_ext>) if
+it is not present in the view name given and no layout template with that exact
+name existed.  (In other words, given a layout name C<main>, if C<main> exists
+in the layouts dir, it will be used; if not, C<main.tmpl> (where C<tmpl> is the
+value of the C<extension> setting, or the value returned by C<default_tmpl_ext>)
+will be looked for.)
+
+=item B<view_exists($view_path)>
+
+By default, Dancer::Template::Abstract checks to see if it can find the
+view file calling C<view_exists($path_to_file)>. If not, it will
+generate a nice error message for the user.
+
+If you are using extending Dancer::Template::Abstract to use a template
+system with multiple document roots (like L<Text::XSlate> or
+L<Template>), you can override this method to always return true, and
+therefore skip this check.
 
 =item B<layout($layout, $tokens, $content)>
 
-The default behavior of this method is to merge a content with a layout.
+The default behavior of this method is to merge a content with a layout.  The
+layout file is looked for with similar logic as per C<view> - an exact match
+first, then attempting to append the default template extension, if the view
+name given did not already end with it.
 
 =item B<render($self, $template, $tokens)>
 
